==> java-micro-2.2.2-20200728.071644-27-sources.jar: com/xunyi/micro/propagation/instrument/reactor/HookRegisteringBeanDefinitionRegistryPostProcessor.java <==
package com.xunyi.micro.propagation.instrument.reactor;

import org.springframework.beans.BeansException;
import org.springframework.beans.factory.BeanFactory;
import org.springframework.beans.factory.config.ConfigurableListableBeanFactory;
import org.springframework.beans.factory.support.BeanDefinitionRegistry;
import org.springframework.beans.factory.support.BeanDefinitionRegistryPostProcessor;
import org.springframework.cloud.sleuth.instrument.reactor.ReactorSleuth;
import reactor.core.publisher.Hooks;
import reactor.core.scheduler.Schedulers;

public class HookRegisteringBeanDefinitionRegistryPostProcessor implements BeanDefinitionRegistryPostProcessor {

    private static final String PROPAGATION_REACTOR_EXECUTOR_SERVICE_KEY = "propagation";

    @Override
    public void postProcessBeanDefinitionRegistry(BeanDefinitionRegistry registry) throws BeansException {

    }

    @Override
    public void postProcessBeanFactory(ConfigurableListableBeanFactory beanFactory) throws BeansException {
        setupHooks(beanFactory);
    }

    void setupHooks(BeanFactory beanFactory) {
//        ConfigurableEnvironment environment = this.context.getEnvironment();
//        boolean decorateOnEach = environment.getProperty(
//                "spring.sleuth.reactor.decorate-on-each", Boolean.class, true);
//        if (decorateOnEach) {
//            if (log.isTraceEnabled()) {
//                log.trace("Decorating onEach operator instrumentation");
//            }
//            Hooks.onEachOperator(SLEUTH_TRACE_REACTOR_KEY,
//                    ReactorSleuth.scopePassingSpanOperator(this.context));
//        }
//        else {
//            if (log.isTraceEnabled()) {
//                log.trace("Decorating onLast operator instrumentation");
//            }
//            Hooks.onLastOperator(SLEUTH_TRACE_REACTOR_KEY,
//                    ReactorSleuth.scopePassingSpanOperator(this.context));
//        }
//        Schedulers.setExecutorServiceDecorator(
//                PROPAGATION_REACTOR_EXECUTOR_SERVICE_KEY,
//                (scheduler,
//                 scheduledExecutorService) -> new TraceableScheduledExecutorService(
//                        beanFactory, scheduledExecutorService));

//        Hooks.onEachOperator(SLEUTH_TRACE_REACTOR_KEY,
//                ReactorSleuth.scopePassingSpanOperator(this.context));
    }
}

==> java-micro-2.2.2-20200807.100124-51-sources.jar: com/xunyi/micro/propagation/instrument/reactor/HookRegisteringBeanDefinitionRegistryPostProcessor.java <==
package com.xunyi.micro.propagation.instrument.reactor;

import org.springframework.beans.BeansException;
import org.springframework.beans.factory.BeanFactory;
import org.springframework.beans.factory.config.ConfigurableListableBeanFactory;
import org.springframework.beans.factory.support.BeanDefinitionRegistry;
import org.springframework.beans.factory.support.BeanDefinitionRegistryPostProcessor;
import org.springframework.cloud.sleuth.instrument.reactor.ReactorSleuth;
import org.springframework.context.ConfigurableApplicationContext;
import reactor.core.publisher.Hooks;
import reactor.core.scheduler.Schedulers;

public class HookRegisteringBeanDefinitionRegistryPostProcessor implements BeanDefinitionRegistryPostProcessor {

    private static final String PROPAGATION_REACTOR_EXECUTOR_SERVICE_KEY = "propagation";




    HookRegisteringBeanDefinitionRegistryPostProcessor() {

    }

    @Override
    public void postProcessBeanDefinitionRegistry(BeanDefinitionRegistry registry) throws BeansException {

    }

    @Override
    public void postProcessBeanFactory(ConfigurableListableBeanFactory beanFactory) throws BeansException {
        setupHooks(beanFactory);
    }

    void setupHooks(BeanFactory beanFactory) {
//        ConfigurableEnvironment environment = this.context.getEnvironment();
//        boolean decorateOnEach = environment.getProperty(
//                "spring.sleuth.reactor.decorate-on-each", Boolean.class, true);
//        if (decorateOnEach) {
//            if (log.isTraceEnabled()) {
//                log.trace("Decorating onEach operator instrumentation");
//            }
//            Hooks.onEachOperator(SLEUTH_TRACE_REACTOR_KEY,
//                    ReactorSleuth.scopePassingSpanOperator(this.context));
//        }
//        else {
//            if (log.isTraceEnabled()) {
//                log.trace("Decorating onLast operator instrumentation");
//            }
//            Hooks.onLastOperator(SLEUTH_TRACE_REACTOR_KEY,
//                    ReactorSleuth.scopePassingSpanOperator(this.context));
//        }
//        Schedulers.setExecutorServiceDecorator(
//                PROPAGATION_REACTOR_EXECUTOR_SERVICE_KEY,
//                (scheduler,
//                 scheduledExecutorService) -> new TraceableScheduledExecutorService(
//                        beanFactory, scheduledExecutorService));

        Hooks.onEachOperator(PROPAGATION_REACTOR_EXECUTOR_SERVICE_KEY,
                Reactors.scopePassingSpanOperator(beanFactory));
    }
}
